==> deepin-screensaver_5.0.18.tar.xz: BUILD/customscreensaver/deepin-custom-screensaver/translations/deepin-custom-screensaver_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="142"/>
        <source>Restore Defaults</source>
        <translation>復原預設</translation>
    </message>
</context>
<context>
    <name>SelectPathWidget</name>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="39"/>
        <source>Picture path</source>
        <translation>選擇圖片路徑</translation>
    </message>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="46"/>
        <source>Select a path of pictures</source>
        <translation>請選擇圖片路徑</translation>
    </message>
</context>
<context>
    <name>SlideShowConfigDialog</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="82"/>
        <source>Custom Screensaver</source>
        <translation>自訂螢幕保護程式</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="129"/>
        <source>Path</source>
        <translation>路徑</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="134"/>
        <source>Shuffle</source>
        <translation>隨機輪播</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="135"/>
        <source>Slideshow</source>
        <translation>輪播設定</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="225"/>
        <source>Picture path</source>
        <translation>選擇圖片路徑</translation>
    </message>
</context>
<context>
    <name>SlideshowScreenSaver</name>
    <message>
        <location filename="../src/slideshowscreensaver.cpp" line="143"/>
        <source>Picture not found</source>
        <translation>圖片不見了</translation>
    </message>
</context>
<context>
    <name>TimeIntervalWidget</name>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="44"/>
        <source>Time interval (s)</source>
        <translation>輪播間隔（秒）</translation>
    </message>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="46"/>
        <source>Range</source>
        <translation>數值範圍</translation>
    </message>
</context>
</TS>

==> deepin-screensaver_6.5.1.tar.xz: BUILD/customscreensaver/deepin-custom-screensaver/translations/deepin-custom-screensaver_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="145"/>
        <source>Restore Defaults</source>
        <translation>復原預設</translation>
    </message>
</context>
<context>
    <name>SelectPathWidget</name>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="39"/>
        <source>Picture path</source>
        <translation>選擇圖片路徑</translation>
    </message>
    <message>
        <location filename="../src/config/selectpathwidget.cpp" line="46"/>
        <source>Select a path of pictures</source>
        <translation>請選擇圖片路徑</translation>
    </message>
</context>
<context>
    <name>SlideShowConfigDialog</name>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="82"/>
        <source>Custom Screensaver</source>
        <translation>自訂螢幕保護程式</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="129"/>
        <source>Path</source>
        <translation>路徑</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="134"/>
        <source>Shuffle</source>
        <translation>隨機輪播</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="135"/>
        <source>Slideshow</source>
        <translation>輪播設定</translation>
    </message>
    <message>
        <location filename="../src/slideshowconfigdialog.cpp" line="228"/>
        <source>Picture path</source>
        <translation>選擇圖片路徑</translation>
    </message>
</context>
<context>
    <name>SlideshowScreenSaver</name>
    <message>
        <location filename="../src/slideshowscreensaver.cpp" line="142"/>
        <source>Please select a valid image path in the Custom Screensaver &quot;Screensaver Setting&quot;.</source>
        <translation>請在自定義屏保“屏保設置”中選擇有效的圖片路徑。</translation>
    </message>
</context>
<context>
    <name>TimeIntervalWidget</name>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="44"/>
        <source>Time interval (s)</source>
        <translation>輪播間隔（秒）</translation>
    </message>
    <message>
        <location filename="../src/config/timeintervalwidget.cpp" line="46"/>
        <source>Range</source>
        <translation>數值範圍</translation>
    </message>
</context>
</TS>
